# 'dunder'.\_\_mifflin\_\_

This packages add `__mifflin__` to all python objects.

    import dunder_mifflin
    'dunder'.__mifflin__()


# License
This packages is distibuted under an Apache License.

# Dependencies
This package uses two dependencies

- asciimatics handles reprinting over existing text on the screen (License Apache)
- forbiddenfruit handles patching the built in types of Python (License GPLv3)